@@ -82,6 +82,7 @@ class Database(core.Construct):
         
         tag_scheduler_uptime_skip (str): to skip optimization check - format Boolean (`true`, `false`)
 
+        character_set_name (str):  For supported engines, specifies the character set to associate with the DB instance (Not applicable to Aurora Cluster)
     """
     @property
     def security_group(self):
@@ -150,6 +151,7 @@ class Database(core.Construct):
         tag_scheduler_uptime="",
         tag_scheduler_uptime_days="",
         tag_scheduler_uptime_skip="",
+        character_set_name=None,
         **kwargs,
     ):
         super().__init__(scope, id, **kwargs)
@@ -356,7 +358,7 @@ class Database(core.Construct):
                 allocated_storage=database_allocated_storage and int(database_allocated_storage),
                 allow_major_version_upgrade=False,
                 database_name=database_name if database_name else None,
-                license_model=_rds.LicenseModel.BRING_YOUR_OWN_LICENSE if is_oracle else None,
+                license_model=_rds.LicenseModel.LICENSE_INCLUDED if is_oracle else None,
                 credentials=credentials,
                 parameter_group=my_parameter_group,
                 instance_type=instance_type,
@@ -373,6 +375,7 @@ class Database(core.Construct):
                 processor_features=None,
                 security_groups=security_groups,
                 storage_encryption_key=encryption_key,
+                character_set_name=character_set_name
             )
 
             # Conditionally create an instance from a snapshot
