@@ -136,7 +136,7 @@ class ServiceUserForIAC(core.Construct):
                         "cloudformation:*",
                     ],
                     resources=[
-                        "arn:aws:cloudformation:eu-west-1:*:stack/" + app_name + "*"
+                        "arn:aws:cloudformation:*:*:stack/" + app_name + "*",
                     ],
                 ),
                 _iam.PolicyStatement(
@@ -192,7 +192,7 @@ class ServiceUserForIAC(core.Construct):
                     actions=[
                         "lambda:*",
                     ],
-                    resources=["arn:aws:lambda:eu-west-1:*:*:" + app_name + "*"],
+                    resources=["arn:aws:lambda:*:*:*:" + app_name + "*"],
                 ),
                 _iam.PolicyStatement(
                     actions=[
@@ -230,6 +230,14 @@ class ServiceUserForIAC(core.Construct):
                         # "arn:aws:iam::*:access-report/" + app_name + "*",
                     ],
                 ),
+                _iam.PolicyStatement(
+                    actions=[
+                        "cloudfront:*",
+                    ],
+                    resources=[
+                        "arn:aws:cloudfront:eu-west-1:*:*:*:*" + app_name + "*",
+                    ],
+                ),
                 # Filter by TAG
                 _iam.PolicyStatement(
                     actions=[
@@ -245,6 +253,7 @@ class ServiceUserForIAC(core.Construct):
                         "logs:*",
                         "iam:*",
                         "elasticfilesystem:*",
+                        "cloudfront:*"
                     ],
                     resources=["*"],
                     conditions={
@@ -267,6 +276,7 @@ class ServiceUserForIAC(core.Construct):
                         "logs:*",
                         "iam:*",
                         "elasticfilesystem:*",
+                        "cloudfront:*"
                     ],
                     resources=["*"],
                     conditions={
@@ -299,12 +309,12 @@ class ServiceUserForIAC(core.Construct):
                         "ssm:List*",
                     ],
                     resources=[
-                        "arn:aws:ssm:eu-west-1:"
+                        "arn:aws:ssm:*:"
                         + account_id
                         + ":parameter/"
                         + app_name
                         + "*",
-                        "arn:aws:ssm:eu-west-1:"
+                        "arn:aws:ssm:*:"
                         + account_id
                         + ":parameter/"
                         + "common/"
