@@ -1,5 +1,6 @@
 from aws_cdk import core, aws_iam as _iam
 from aws_cdk.core import Tags
+from aws_cdk_constructs.utils import normalize_environment_parameter
 
 class ServiceUserForStaticAssets(core.Construct):
     """Construct to create the Service User to deploy the project static files from a CD/CI pipeline
@@ -27,6 +28,7 @@ class ServiceUserForStaticAssets(core.Construct):
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
+        environment = normalize_environment_parameter(environment)
 
         # Apply mandatory tags
         Tags.of(self).add("ApplicationName", app_name.lower().strip())
